<?php

define('API_DIRECTORY', dirname( __FILE__ ) , True);

// load libraries
require_once(API_DIRECTORY.'/../library/tonic/lib/tonic.php'); 
require_once(API_DIRECTORY.'/../library/utils/Errors.php');

// load adapters
require_once(API_DIRECTORY."/../adapters/ExpressoAdapter.php");
require_once(API_DIRECTORY."/../adapters/MailAdapter.php");
require_once(API_DIRECTORY."/../adapters/CatalogAdapter.php");
require_once(API_DIRECTORY."/../adapters/CalendarAdapter.php");
require_once(API_DIRECTORY."/../adapters/AdminAdapter.php" );

// Load all resources
require_once(API_DIRECTORY."/admin/CreateUserResource.php");
require_once(API_DIRECTORY."/admin/DeleteUserResource.php");
require_once(API_DIRECTORY."/admin/GetUsersResource.php");
require_once(API_DIRECTORY."/admin/RenameUserResource.php");
require_once(API_DIRECTORY."/admin/UpdateUserResource.php");

require_once(API_DIRECTORY."/availableServers/AvailableServersResource.php");

require_once(API_DIRECTORY."/core/ExpressoVersionResource.php");
require_once(API_DIRECTORY."/core/LoginResource.php");
require_once(API_DIRECTORY."/core/LogoutResource.php");

require_once(API_DIRECTORY."/mail/FoldersResource.php");
require_once(API_DIRECTORY."/mail/MessagesResource.php");
require_once(API_DIRECTORY."/mail/AddFolderResource.php");
require_once(API_DIRECTORY."/mail/DelFolderResource.php");
require_once(API_DIRECTORY."/mail/DelMessageResource.php");
require_once(API_DIRECTORY."/mail/RenameFolderResource.php");
require_once(API_DIRECTORY."/mail/CleanTrashResource.php");
require_once(API_DIRECTORY."/mail/AttachmentResource.php");
require_once(API_DIRECTORY."/mail/SendResource.php");
require_once(API_DIRECTORY."/mail/SendSupportFeedbackResource.php");

require_once(API_DIRECTORY."/catalog/ContactsResource.php");
require_once(API_DIRECTORY."/catalog/ContactPictureResource.php");
require_once(API_DIRECTORY."/calendar/EventsResource.php");


//Retrieveing the mapping of the URIs and his respectives classNames and classPath
$config 	= parse_ini_file( API_DIRECTORY . '/../config/Tonic.srv', true );
$autoload 	= array();
$classpath 	= array();

foreach( $config as $uri => $classFile )
{
	foreach( $classFile as $className => $filePath )
	{
		$autoload[ $uri ] = $className;
		$classpath[ $className ] = $filePath;
	}

	$request = new Request(array(
			'baseUri' => dirname($_SERVER['SCRIPT_NAME']),
			'autoload' => $autoload
	));
}
	
try {

	$resource = $request->loadResource();
	$response = $resource->exec($request);
	
} catch (ResponseException $e) {
	
	switch ($e->getCode()) {
		
		case Response::UNAUTHORIZED:
			$response = $e->response($request);
			$response->addHeader('WWW-Authenticate', 'Basic realm="Tonic"');
			break;
		default:
			
			$response = new Response($request);
			$response->code = Response::OK;
			$response->addHeader('content-type', 'application/json');
			if($request->id)
				$body['id']	= $request->id;
			
			$body['error'] = array("code" => "".$e->getCode(), "message" => $e->getMessage());
			$response->body = json_encode($body);
	}
}

$response->output();

?>
